@@ -54,18 +54,6 @@ tree_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data
 	
 }
 
-static void
-threads_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfValue *value = gconf_entry_get_value (entry);
-	
-	procdata->config.show_threads = gconf_value_get_bool (value);
-	proctable_clear_tree (procdata);
-	proctable_update_all (procdata);
-	
-}
-
 static void
 view_as_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 {
@@ -202,10 +190,6 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 	else {
 		g_assert_not_reached();
 	}
-
-	load_graph_reset_colors(procdata->cpu_graph);
-	load_graph_reset_colors(procdata->mem_graph);
-	load_graph_reset_colors(procdata->net_graph);
 }
 
 
@@ -231,8 +215,6 @@ procman_data_new (GConfClient *client)
 	gint swidth, sheight;
 	gint i;
 	glibtop_cpu cpu;
-	glibtop_loadavg loadavg;
-	gsize nprocs;
 
 	pd = g_new0 (ProcData, 1);
 	
@@ -247,10 +229,6 @@ procman_data_new (GConfClient *client)
 	pd->net_graph = NULL;
 	pd->disk_timeout = 0;
 
-	glibtop_get_loadavg(&loadavg);
-	nprocs = (loadavg.nr_tasks ? 1.2f * loadavg.nr_tasks : 100);
-	pd->procinfo_allocator = g_mem_chunk_create(ProcInfo, nprocs, G_ALLOC_AND_FREE);
-
 	/* username is usually 8 chars long
 	   for caching, we create chunks of 128 chars */
 	pd->users = g_string_chunk_new(128);
@@ -270,9 +248,6 @@ procman_data_new (GConfClient *client)
 							      NULL);
 	gconf_client_notify_add (client, "/apps/procman/hide_message", warning_changed_cb,
 				 pd, NULL, NULL);
-	pd->config.show_threads = gconf_client_get_bool (client, "/apps/procman/show_threads", NULL);
-	gconf_client_notify_add (client, "/apps/procman/show_threads", threads_changed_cb,
-				 pd, NULL, NULL);
 	pd->config.update_interval = gconf_client_get_int (client, "/apps/procman/update_interval", 
 							   NULL);
 	gconf_client_notify_add (client, "/apps/procman/update_interval", timeouts_changed_cb,
@@ -409,6 +384,7 @@ procman_free_data (ProcData *procdata)
 {
 
 	proctable_free_table (procdata);
+	g_string_chunk_free(procdata->users);
 	g_hash_table_destroy(procdata->pids);
 	pretty_table_free (procdata->pretty_table);
 	smooth_refresh_destroy(procdata->smooth_refresh);
@@ -481,7 +457,7 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefi
 		}
 	}
 
-	if(g_str_has_suffix(prefix, "proctree"))
+	if(g_str_has_suffix(prefix, "proctree") || g_str_has_suffix(prefix, "disktreenew"))
 	{
 		GSList *order;
 		char *key;
@@ -548,7 +524,7 @@ procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *pref
 		g_free (key);
 	}
 
-	if(g_str_has_suffix(prefix, "proctree"))
+	if(g_str_has_suffix(prefix, "proctree") || g_str_has_suffix(prefix, "disktreenew"))
 	{
 		GSList *order;
 		char *key;
@@ -714,6 +690,7 @@ main (int argc, char *argv[])
 	}
 
 	gtk_window_set_default_icon_name ("gnome-monitor");
+	g_set_application_name(_("System Monitor"));
 		    
 	gconf_init (argc, argv, NULL);
 			    
