@@ -36,10 +36,12 @@ enum
 	COL_MEMXSERVER,
 	COL_CPU,
 	COL_CPU_TIME,
+	COL_START_TIME,
 	COL_NICE,
 	COL_PID,
 	COL_SECURITYCONTEXT,
 	COL_ARGS,
+	COL_MEM,
 	COL_PIXBUF,
 	COL_POINTER,
 	NUM_COLUMNS
